@@ -14,44 +14,44 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
-Cylc Rose
-=========
+Rose Suite Configurations
+=========================
 
-Cylc Rose is the bridge between Rose suite configurations and Cylc workflows.
-
-Cylc Rose allows ``cylc install`` to replace the ``rose suite-run``
-command (present in Rose versions 2019.01 and earlier). It reads the
-``rose-suite.conf`` file and:
-
-- Makes environment and template variables available
-  to Cylc.
-- Installs files.
-- Records information in about the configuration installed in
-  ``~/cylc-run/<workflow>/opt/rose-suite-cylc-install.conf``
+This plugin is activated by the existence of a Rose Suite Configuration file
+(called ``rose-suite.conf``) in the workflow definition directory which allows
+you to:
 
+- Set template variables used in the workflow definition.
+- Configure files to be installed via ``cylc install``.
+- Define environment variables for the Cylc scheduler.
 
 The following Cylc commands will read Rose Suite Configurations:
 
+- ``cylc install``
 - ``cylc validate``
 - ``cylc graph``
 - ``cylc list``
 - ``cylc config``
 
+.. Note::
 
-Rose Config
------------
+   Cylc Rose allows ``cylc install`` to replace the ``rose suite-run``
+   command (present in Rose versions 2019.01 and earlier).
+
+
+Configuration File
+------------------
 
 .. attention::
 
-   Rose configurations for Cylc **workflows** continue to be referred to
-   as Rose **suites**.
+   Although we now refer to Cylc **workflows** (rather than **suites**) we
+   continue to refer to the ``rose-suite.conf`` file as a Rose Suite
+   Configuration.
 
 A fuller description of
-:ref:`rose suite config is available here<Rose Suites>`.
+:ref:`Rose Suite Configuration is available here<Rose Suites>`.
 
-Cylc-rose allows you to set environment and template variables in a
-configuration file called ``rose-suite.conf``. The following sections are
-permitted in the ``rose-suite.conf`` files:
+The following sections are permitted in the ``rose-suite.conf`` files:
 
 .. csv-table::
    :header: config item, description
@@ -65,7 +65,7 @@ permitted in the ``rose-suite.conf`` files:
 
 .. note::
 
-   For compatibility with Cylc 7 sections ``[suite.rc:empy]`` and
+   For compatibility with Cylc 7, sections ``[suite.rc:empy]`` and
    ``[suite.rc:jinja2]`` will be processed, but are deprecated and provided
    for ease of porting Cylc 7 workflows.
 
@@ -121,8 +121,8 @@ have Cylc Rose installed see ``cylc install --help``.
 Cylc Install Optional Config
 ----------------------------
 
-If Cylc-Rose is installed, using ``cylc install`` with a Rose Suite will
-write a record of command line options set in
+If Cylc-Rose is installed, using ``cylc install`` with a workflow containing a
+Rose Suite Configuration will write a record of command line options set in
 ``$CYLC_RUN_DIR/workflow_name/opt/rose-suite-cylc-install.conf``.
 
 
@@ -205,4 +205,4 @@ configuration file ``~/cylc-run/my_workflow/opt/rose-suite-cylc-install.conf``.
 
 """
 
-__version__ = '1.0.0'
+__version__ = '1.0.2'
