@@ -17,9 +17,7 @@
 # You should have received a copy of the GNU General Public License
 # along with Rose. If not, see <http://www.gnu.org/licenses/>.
 # -----------------------------------------------------------------------------
-"""Cylc 8 implementation of 'rose stem'
-
-Provide a wrapper around "cylc install" for rose-stem suites.
+"""Install a rose-stem suite using cylc install.
 
 To run a rose-stem suite use "cylc play".
 """
@@ -221,7 +219,7 @@ class StemRunner:
             raise ProjectNotFoundException(item, stderr)
 
         ret = {}
-        for line in output.decode().splitlines():
+        for line in output.splitlines():
             if ":" not in line:
                 continue
             key, value = line.split(":", 1)
@@ -236,7 +234,7 @@ class StemRunner:
         if source_dict['project']:
             repo += '/' + source_dict['project']
 
-        kpoutput = self.popen.run('fcm', 'kp', source_dict['url'])[1].decode()
+        kpoutput = self.popen.run('fcm', 'kp', source_dict['url'])[1]
         project = None
         for line in kpoutput.splitlines():
             if line.rstrip().endswith(repo):
