@@ -31,13 +31,16 @@ from metomi.isodatetime.datetimeoper import DateTimeOperator
 from metomi.rose.config import ConfigDumper, ConfigNodeDiff, ConfigNode
 from metomi.rose.config_processor import ConfigProcessError
 from metomi.rose.env import env_var_process, UnboundEnvironmentVariableError
-from metomi.rose.resource import ResourceLocator
 
 if TYPE_CHECKING:
     from optparse import Values
 
 
 SECTIONS = {'jinja2:suite.rc', 'empy:suite.rc', 'template variables'}
+SET_BY_CYLC = 'set by Cylc'
+ROSE_ORIG_HOST_INSTALLED_OVERRIDE_STRING = (
+    ' ROSE_ORIG_HOST set by cylc install.'
+)
 
 
 class MultipleTemplatingEnginesError(Exception):
@@ -75,21 +78,38 @@ def get_rose_vars_from_config_node(config, config_node, environ):
     if templating not in config_node.value:
         config_node.set([templating])
 
-    # Get Rose Orig host if it's not in definition.
-    rose_orig_host = None
-    if 'ROSE_ORIG_HOST' not in config_node['env']:
-        rose_orig_host = get_host()
-
-    # Get Values for standard ROSE variables (ROSE_ORIG_HOST and ROSE_SITE).
-    rose_site = ResourceLocator().get_conf().get_value(['site'], '')
+    # Get Rose Orig host:
+    rose_orig_host = get_host()
 
     # For each section process variables and add standard variables.
     for section in ['env', templating]:
-        # Add standard ROSE_VARIABLES
-        config_node[section].set(['ROSE_SITE'], rose_site)
-        config_node[section].set(['ROSE_VERSION'], ROSE_VERSION)
-        if rose_orig_host:
-            config_node[section].set(['ROSE_ORIG_HOST'], rose_orig_host)
+
+        # This loop handles standard variables.
+        # CYLC_VERSION - If it's in the config, remove it.
+        # ROSE_VERSION - If it's in the config, replace it.
+        # ROSE_ORIG_HOST - If it's the config, replace it, unless it has a
+        # comment marking it as having been saved by ``cylc install``.
+        # In all cases warn users if the value in their config is not used.
+        for var_name, replace_with in [
+            ('ROSE_ORIG_HOST', rose_orig_host),
+            ('ROSE_VERSION', ROSE_VERSION),
+            ('CYLC_VERSION', SET_BY_CYLC)
+        ]:
+            # Warn if we're we're going to override a variable:
+            if override_this_variable(config_node, section, var_name):
+                user_var = config_node[section].value[var_name].value
+                LOG.warning(
+                    f'[{section}]{var_name}={user_var} from rose-suite.conf '
+                    f'will be ignored: {var_name} will be: {replace_with}'
+                )
+
+            # Handle replacement of stored variable if appropriate:
+            if replace_with == SET_BY_CYLC:
+                config_node[section].unset([var_name])
+            elif not rose_orig_host_set_by_cylc_install(
+                config_node, section, var_name
+            ):
+                config_node[section].set([var_name], replace_with)
 
         # Use env_var_process to process variables which may need expanding.
         for key, node in config_node.value[section].value.items():
@@ -187,15 +207,8 @@ def rose_config_exists(
     if srcdir is None:
         return False
 
-    # If _any_ of the following are true we want to return True.
-    if (
-        Path(srcdir, 'rose-suite.conf').is_file() or
-        opts and opts.opt_conf_keys or
-        opts and opts.defines or
-        opts and opts.rose_template_vars
-    ):
-        return True
-    return False
+    # Return true if and only if the rose suite.conf exists.
+    return Path(srcdir, 'rose-suite.conf').is_file()
 
 
 def rose_config_tree_loader(srcdir=None, opts=None):
@@ -517,3 +530,80 @@ def paths_to_pathlib(paths):
         else None
         for path in paths
     ]
+
+
+def override_this_variable(node, section, variable):
+    """Variable exists in this section of the config and should be replaced
+    because it is a standard variable.
+
+    Examples:
+        Setup:
+        >>> from metomi.rose.config import ConfigNode
+        >>> from cylc.rose.utilities import (
+        ... ROSE_ORIG_HOST_INSTALLED_OVERRIDE_STRING as rohios
+        ... )
+        >>> node = ConfigNode()
+        >>> node = node.set(['env'])
+
+        1. Variable not in node[section]:
+        >>> override_this_variable(node, 'env', 'foo')
+        False
+
+        2. Variable is not ROSE_ORIG_HOST:
+        >>> node = node.set(['env', 'ROSE_VERSION'], '123.456')
+        >>> override_this_variable(node, 'env', 'ROSE_VERSION')
+        True
+
+        3. Variable is ROSE_ORIG_HOST and override string unset:
+        >>> node = node.set(['env', 'ROSE_ORIG_HOST'], '123.456.789.10')
+        >>> override_this_variable(node, 'env', 'ROSE_ORIG_HOST')
+        True
+
+        4. Variable is ROSE_ORIG_HOST and override string set:
+        >>> node['env']['ROSE_ORIG_HOST'].comments = [rohios]
+        >>> override_this_variable(node, 'env', 'ROSE_ORIG_HOST')
+        False
+    """
+    if variable not in node[section]:
+        return False
+    elif (
+        variable != 'ROSE_ORIG_HOST'
+        or (
+            ROSE_ORIG_HOST_INSTALLED_OVERRIDE_STRING not in
+            node[section][variable].comments
+        )
+    ):
+        return True
+    return False
+
+
+def rose_orig_host_set_by_cylc_install(node, section, var):
+    """ROSE_ORIG_HOST exists in node and is commented by Cylc Install to avoid
+    it being overridden by Cylc Rose.
+
+    Examples:
+        Setup:
+        >>> from metomi.rose.config import ConfigNode
+        >>> from cylc.rose.utilities import (
+        ... ROSE_ORIG_HOST_INSTALLED_OVERRIDE_STRING as rohios
+        ... )
+        >>> node = ConfigNode()
+
+        ROSE_ORIG_HOST set by user, without the comment which Cylc install
+        would add:
+        >>> node = node.set(['env', 'ROSE_ORIG_HOST'], 'IMPLAUSIBLE_HOST_NAME')
+        >>> rose_orig_host_set_by_cylc_install(node, 'env', 'ROSE_ORIG_HOST')
+        False
+
+        ROSE_ORIG_HOST set by Cylc install, with a comment saying so:
+        >>> node['env']['ROSE_ORIG_HOST'].comments = rohios
+        >>> rose_orig_host_set_by_cylc_install(node, 'env', 'ROSE_ORIG_HOST')
+        True
+    """
+    if (
+        var in node[section]
+        and ROSE_ORIG_HOST_INSTALLED_OVERRIDE_STRING in
+        node[section][var].comments
+    ):
+        return True
+    return False
